/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.pdfbox.pdmodel.font;

//import java.awt.Image;

import java.io.IOException;

import java.util.List;

import org.apache.fontbox.util.BoundingBox;

import org.apache.pdfbox.cos.COSNumber;
import org.apache.pdfbox.cos.COSStream;

import org.apache.pdfbox.pdmodel.graphics.xobject.PDInlinedImage;

import org.apache.pdfbox.util.ImageParameters;
import org.apache.pdfbox.util.PDFOperator;
import org.apache.pdfbox.util.PDFStreamEngine;

/**
 * This class will handle creating an image for a type 3 glyph.
 *
 * @author <a href="mailto:ben@benlitchfield.com">Ben Litchfield</a>
 * @version $Revision: 1.10 $
 */
public class Type3StreamParser extends PDFStreamEngine
{
    private PDInlinedImage image = null;
    private BoundingBox box = null;


    /**
     * This will parse a type3 stream and create an image from it.
     *
     * @param type3Stream The stream containing the operators to draw the image.
     *
     * @return The image that was created.
     *
     * @throws IOException If there is an error processing the stream.
     */
 /*   public Image createImage( COSStream type3Stream ) throws IOException
    {
        processStream( null, null, type3Stream );
        return image.createImage();
    }*/

    /**
     * This is used to handle an operation.
     *
     * @param operator The operation to perform.
     * @param arguments The list of arguments.
     *
     * @throws IOException If there is an error processing the operation.
     */
    protected void processOperator( PDFOperator operator, List arguments ) throws IOException
    {
        super.processOperator( operator, arguments );
        String operation = operator.getOperation();
        if( operation.equals( "BI" ) )
        {
            ImageParameters params = operator.getImageParameters();
            image = new PDInlinedImage();
            image.setImageParameters( params );
            image.setImageData( operator.getImageData() );
            //begin inline image object
        }if( operation.equals( "d0" ) )
        {
            //set glyph with for a type3 font
            //COSNumber horizontalWidth = (COSNumber)arguments.get( 0 );
            //COSNumber verticalWidth = (COSNumber)arguments.get( 1 );
            //width = horizontalWidth.intValue();
            //height = verticalWidth.intValue();
        }
        else if( operation.equals( "d1" ) )
        {
            //set glyph with and bounding box for type 3 font
            //COSNumber horizontalWidth = (COSNumber)arguments.get( 0 );
            //COSNumber verticalWidth = (COSNumber)arguments.get( 1 );
            COSNumber llx = (COSNumber)arguments.get( 2 );
            COSNumber lly = (COSNumber)arguments.get( 3 );
            COSNumber urx = (COSNumber)arguments.get( 4 );
            COSNumber ury = (COSNumber)arguments.get( 5 );

            //width = horizontalWidth.intValue();
            //height = verticalWidth.intValue();
            box = new BoundingBox();
            box.setLowerLeftX( llx.floatValue() );
            box.setLowerLeftY( lly.floatValue() );
            box.setUpperRightX( urx.floatValue() );
            box.setUpperRightY( ury.floatValue() );
        }
    }


}
