/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.pdfbox.util;


import java.io.InputStream;
import java.io.IOException;

import java.util.Properties;

import bse.testPDFBox.R;
/**
 * This class will handle loading resource files(AFM/CMAP).
 *
 * @author <a href="mailto:ben@benlitchfield.com">Ben Litchfield</a>
 * @version $Revision: 1.9 $
 */
public class ResourceLoader {
	
	private static String GLYPHLIST = "Resources/glyphlist.txt";
	private static String HELVETICA_BOLDOBLIQUE = "helvetica_boldoblique.afm";
	private static String HELVETICA_BOLD = "helvetica_bold.afm";
	private static String HELVETICA = "helvetica.afm";
	private static String HELVETICA_OBLIQUE = "helvetica_oblique.afm";
	private static String SYMBOL = "symbol.afm";
	private static String ARIAL = "arialmt.ttf";
	private static String ARIAL_BOLD = "arial_boldmt.ttf";
	private static String ARIAL_BOLDITALIC = "arial_bolditalicmt.ttf";
	private static String COURIER = "courier.afm";
	private static String COURIER_BOLD = "courier_bold.afm";
	private static String COURIER_BOLDOBLIQUE = "courier_boldoblique.afm";
	private static String COURIER_OBLIQUE = "courier_oblique.afm";
	private static String TIMES_BOLD = "times_bold.afm";
	private static String TIMES_ROMAN = "times_roman.afm";
	private static String TIMES_ITALIC = "times_italic.afm";
	private static String TIMES_BOLDITALIC = "times_bolditalic.afm";
	private static String ZAPFDINGBATS = "zapfdingbats.afm";
	
	
	
    /**
     * private constructor for utility class.
     */
    private ResourceLoader()
    {
        //private utility class
    }

    /**
     * This will attempt to load the resource given the resource name.
     *
     * @param resourceName The resource to try and load.
     *
     * @return The resource as a stream or null if it could not be found.
     *
     * @throws IOException If there is an error while attempting to load the resource.
     */
    public static InputStream loadResource(final String resourceName ) throws IOException
    {
        ClassLoader loader = ResourceLoader.class.getClassLoader();

        InputStream is = null;
    //    android.util.Log.d("TestPDFBox","pdfbox.util.ResourceLoader.loadResource() 1\tloader="+loader+"\tresourceName="+resourceName);
        if( loader != null )
        {
            is = loader.getResourceAsStream( resourceName );
        }

        //see sourceforge bug 863053, this is a fix for a user that
        //needed to have PDFBox loaded by the bootstrap classloader
        if( is == null )
        {
            loader = ClassLoader.getSystemClassLoader();
      //      android.util.Log.d("TestPDFBox","pdfbox.util.ResourceLoader.loadResource() 2\tloader="+loader+"\tresourceName="+resourceName);
           if( loader != null )
            {
                is = loader.getResourceAsStream( resourceName );
            }
        }

        if( is == null )		        {
   //         android.util.Log.d("TestPDFBox","pdfbox.util.ResourceLoader.loadResource() 3\tUsing filename="+loader+"\tresourceName="+resourceName);
         
            if(resourceName.equals(GLYPHLIST))
            	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.glyphlist);
            else if(resourceName.equals(ARIAL))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.arialmt);
            else if(resourceName.equals(ARIAL_BOLD))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.arial_boldmt);
            else if(resourceName.equals(ARIAL_BOLDITALIC))
                is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.arial_bolditalicmt);
            else if(resourceName.equals(COURIER))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.courier);
            else if(resourceName.equals(COURIER_BOLD))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.courier_bold);
            else if(resourceName.equals(COURIER_BOLDOBLIQUE))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.courier_boldoblique);
            else if(resourceName.equals(COURIER_OBLIQUE))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.courier_oblique);
            else if(resourceName.equals(HELVETICA_BOLDOBLIQUE))
              	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.helvetica_boldoblique);
            else if(resourceName.equals(HELVETICA_BOLD))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.helvetica_bold);
            else if(resourceName.equals(HELVETICA))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.helvetica);
            else if(resourceName.equals(HELVETICA_OBLIQUE))
              	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.helvetica_oblique);
            else if(resourceName.equals(SYMBOL))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.symbol);
            else if(resourceName.equals(TIMES_BOLD))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.times_bold);
            else if(resourceName.equals(TIMES_ROMAN))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.times_roman);
            else if(resourceName.equals(TIMES_ITALIC))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.times_italic);
            else if(resourceName.equals(TIMES_BOLDITALIC))
              	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.times_bolditalic);
            else if(resourceName.equals(ZAPFDINGBATS))
               	is = bse.testPDFBox.TestPDFBoxActivity.resources.openRawResource(R.raw.zapfdingbats);
            
        }
  //      android.util.Log.d("TestPDFBox","pdfbox.util.ResourceLoader.loadResource() 4\tReturn is="+is);
        
        return is;
    }

    /**
     * This will attempt to load the resource given the resource name.
     *
     * @param resourceName The resource to try and load.
     * @param failIfNotFound Throw an error message if the properties were not found.
     *
     * @return The resource as a stream or null if it could not be found.
     *
     * @throws IOException If there is an error loading the properties.
     */
    public static Properties loadProperties(final String resourceName, final boolean failIfNotFound ) throws IOException
    {
        Properties properties = null;
        InputStream is = null;
        try
        {
        	android.util.Log.d("TestPDFBox","ResourceLoader.loadProperties() 1\tresourceName="+resourceName);
        	is = loadResource( resourceName );
            if( is != null )
            {
                properties = new Properties();
                properties.load( is );
            }
            else
            {
                if( failIfNotFound )
                {
                    throw new IOException( "Error: could not find resource '" + resourceName + "' on classpath." );
                }
            }
        }
        finally
        {
         	android.util.Log.d("TestPDFBox","ResourceLoader.loadProperties() 2\tis="+is);
            if( is != null )
            {
                is.close();
            }
        }
        return properties;
    }

    /**
     * This will attempt to load the resource given the resource name.
     *
     * @param resourceName The resource to try and load.
     * @param defaults A stream of default properties.
     *
     * @return The resource as a stream or null if it could not be found.
     *
     * @throws IOException If there is an error loading the properties.
     */
    public static Properties loadProperties(final String resourceName, final Properties defaults ) throws IOException
    {
        InputStream is = null;
        try
        {
          	android.util.Log.d("TestPDFBox","ResourceLoader.loadProperties() 3\tresourceName="+resourceName);
          is = loadResource( resourceName );
            if( is != null )
            {
                defaults.load( is );
            }
        }
        finally
        {
        	android.util.Log.d("TestPDFBox","ResourceLoader.loadProperties() 4\tis="+is);
          if( is != null )
            {
                is.close();
            }
        }
        return defaults;
    }
}
